@@ -57,6 +57,8 @@
 #include <sipwitch/rtpproxy.h>
 #endif
 
+#define	CONFIG_KEY_SIZE 177
+
 NAMESPACE_SIPWITCH
 using namespace UCOMMON_NAMESPACE;
 
@@ -64,6 +66,7 @@ class __EXPORT service : public memalloc
 {
 public:
 	typedef treemap<char *>keynode;
+	typedef	enum {EXT_DIALING, USER_DIALING, ALL_DIALING} dialmode_t;
 
 	typedef struct {
 		const char *key;
@@ -89,18 +92,18 @@ public:
 		pointer(pointer const&);
 		~pointer();
 		
-		inline operator bool()
+		inline operator bool() const
 			{return node != NULL;};
 
-		inline bool operator!()
+		inline bool operator!() const
 			{return node == NULL;};
 
 		void operator=(keynode *node);
 
-		inline keynode *operator*()
+		inline keynode *operator*() const
 			{return node;};
 
-		inline keynode *operator->()
+		inline keynode *operator->() const
 			{return node;};
 	};
 
@@ -113,7 +116,7 @@ public:
 		instance();
 		~instance();
 		
-		inline const service *operator->()
+		inline const service *operator->() const
 			{return service::cfg;};
 	};
 
@@ -122,14 +125,13 @@ public:
 	protected:
 		friend class service;
 
-		const char *id;
 		unsigned runlevel;
 		bool active_flag;
 
 		static LinkedObject *runlevels[4];
 		static unsigned count;
 
-        callback(int level = 0, const char *id = NULL);
+        callback(int level = 0);
         virtual ~callback();
 
 		inline static void *alloc(service *cfgp, size_t size)
@@ -138,25 +140,24 @@ public:
 		inline static char *dup(service *cfgp, const char *s)
 			{return cfgp->dup(s);};
 
-		inline static bool isConfigured(void)
+		inline static bool isConfigured(void) 
 			{return service::cfg != NULL;};
 
-		inline bool isActive(void)
+		inline bool isActive(void) const
 			{return active_flag;};
 
 		virtual bool check(void);
-		virtual void activating(MappedRegistry *rr);
-		virtual void expiring(MappedRegistry *rr);
 		virtual void snapshot(FILE *fp);
 		virtual void start(service *cfg);
 		virtual void stop(service *cfg);
-		virtual bool reload(service *cfg);
-		virtual bool classifier(rtpproxy::session *session, rtpproxy::session *source, struct sockaddr *addr); 
+		virtual void reload(service *cfg);
     };
     
 	service(const char *name, size_t s = 0);
 	virtual ~service();
 
+	static volatile dialmode_t dialmode;
+
 	bool load(FILE *fp, keynode *node = NULL);
 	keynode *getPath(const char *path);
 	keynode *getNode(keynode *base, const char *id, const char *value);	
@@ -165,7 +166,10 @@ public:
 	keynode *getNode(keynode *base, const char *grp, const char *attr, const char *value);
 	keynode *getList(const char *path);
 
-	inline static bool isLinked(keynode *node)
+	inline static LinkedObject *getModules(void)
+		{return service::callback::runlevels[3];};
+
+	inline static bool isLinked(keynode *node) 
 		{return node->isLeaf();};
 
 	inline static bool isValue(keynode *node)
@@ -176,14 +180,13 @@ public:
 
 	inline static bool isNode(keynode *node)
 		{return isLinked(node) && isValue(node);};
-
+	
 	static const char *getValue(keynode *base, const char *id);
 	static void dump(FILE *fp, keynode *node, unsigned level);
 	static void snapshot(const char *uid);
 	static void dumpfile(const char *uid);
 	static void result(const char *value);
 	static FILE *open(const char *uid = NULL, const char *cfgpath = NULL);
-	static bool state(const char *value);
 	static void startup(void);
 	static void shutdown(void);
 	static void snmptrap(unsigned id, const char *descr);
@@ -191,8 +194,8 @@ public:
 	static bool match(const char *digits, const char *pattern, bool partial);
 	static keynode *get(void);
 
-	static callback *getComponent(const char *id);
 	static keynode *getProtected(const char *path);
+	static keynode *getUser(const char *uid);
 	static keynode *path(const char *p);
 	static keynode *list(const char *p);
 
@@ -200,26 +203,28 @@ public:
 		{return getProtected("environ");};
 
 	virtual void dump(FILE *fp);
-	virtual bool confirm(const char *user);
-	bool commit(const char *user);
+	virtual void confirm(const char *user);
+	void commit(const char *user);
 
-	static bool classify(rtpproxy::session *session, rtpproxy::session *source, struct sockaddr *addr);
-	static void activate(MappedRegistry *rr);
-	static void expire(MappedRegistry *rr);
 	static bool check(void);
 	static void release(keynode *node);
 
-	static inline bool isProxied(void)
-		{return classify(NULL, NULL, NULL);};
-
 protected:
 	friend class instance;
 
-	static service *cfg;
-	static condlock_t locking;
+	class __LOCAL keymap : public LinkedObject
+	{
+	public:
+		service::keynode *node;
+		const char *id;
+	};
 	
 	keynode root;
 	stringbuf<1024> buffer;
+	LinkedObject *keys[CONFIG_KEY_SIZE];
+
+	static service *cfg;
+	static condlock_t locking;
 
 	void setHeader(const char *header);
 	void clearId(void);
@@ -238,6 +243,8 @@ private:
 };
 
 #define	RUNLEVELS	(sizeof(callback::runlevels) / sizeof(LinkedObject *))
+#define	MODULE_RUNLEVEL	(RUNLEVELS - 1)
+#define	GENERIC_RUNLEVEL (RUNLEVELS - 2)
 
 
 END_NAMESPACE
