@@ -32,10 +32,11 @@ public:
 		MappedRegistry *entry;
 	};
 
-	volatile char *proxy;
-	volatile char *realm;
-	volatile char *digest;
-	volatile char *server;
+	char *volatile proxy;
+	char *volatile realm;
+	char *volatile digest;
+	char *volatile server;
+	char *volatile refer;
 	time_t	expires;
 	bool enabled;
 	condlock_t locking;
@@ -58,6 +59,7 @@ private:
 	void expiring(MappedRegistry *rr);
 	void registration(int id, modules::regmode_t mode);
 	void authenticate(int id, const char *remote_realm);
+	char *referLocal(MappedRegistry *rr, const char *target, char *buffer, size_t size);
 };
 
 static forward forward_plugin;
@@ -67,8 +69,9 @@ modules::sipwitch()
 {
 	process::errlog(INFO, "server forward plugin loaded");	
 	enabled = false;
-	digest = (volatile char *)"MD5";
-	realm = (volatile char *)"GNU Telephony";
+	refer = NULL;
+	digest = (char *)"MD5";
+	realm = (char *)"GNU Telephony";
 	proxy = NULL;
 	freelist = NULL;
 	memset(index, sizeof(index), 0);
@@ -151,9 +154,8 @@ void forward::reload(service *cfg)
 	char *cp;
 	unsigned len;
 	char buffer[160];
-	struct sockaddr *address;
+	bool refering = false;
 	bool enable = false;
-	unsigned port;
 	const char *key = NULL, *value;
 	char *tmp_realm = (char *)realm, *tmp_digest = cfg->dup((char *)digest);
 	linked_pointer<service::keynode> fp = cfg->getList("forward");
@@ -175,49 +177,25 @@ void forward::reload(service *cfg)
 		key = fp->getId();
 		value = fp->getPointer();
 		if(key && value) {
-			if(String::equal(key, "server")) {
-				if(String::equal(value, "sip:", 4))
-					value += 4;
-				else if(String::equal(value, "sips:", 5))
-					value += 5;
-				
-				if(*cp == '[') {
-					String::set(buffer, sizeof(buffer), value + 1);
-					cp = strchr(buffer, ']');
-					if(cp)
-						*(cp++) = 0;
-					if(cp && *cp == ':')
-						++cp;
+			if(String::equal(key, "refer")) {
+				if(uri::resolve(value, buffer, sizeof(buffer))) {
+					refer = cfg->dup(buffer);
+					refering = true;
+					debug(2, "forward refer resolved as %s", buffer);
 				}
 				else {
-					String::set(buffer, sizeof(buffer), value);
-					cp = strchr(buffer, ':');
-					if(cp)
-						*(cp++) = 0;
+					process::errlog(ERRLOG, "forward: %s: cannot resolve", value);
+					server = NULL;
+				}
+			}
+			else if(String::equal(key, "server")) {
+				if(uri::resolve(value, buffer, sizeof(buffer))) {
+					server = cfg->dup(buffer);
+					debug(2, "forward server resolved as %s", buffer);
 				}
-				if(Socket::isNumeric(buffer))
-					server = cfg->dup(value);
 				else {
-					Socket::address resolve;
-					port = 0;
-					if(cp && *cp)
-						port = atoi(cp);
-					resolve.set(buffer, port);
-					address = resolve.getAddr();
-					if(address) {
-						Socket::getaddress(address, buffer, sizeof(buffer));	
-						len = strlen(buffer);
-						port = Socket::getservice(address);
-						if(!port)
-							port = 5060;
-						snprintf(buffer + len, sizeof(buffer) - len, ":%u", port);
-						server = cfg->dup(buffer);
-						debug(2, "forward server resolved as %s", buffer);
-					}
-					else {
-						process::errlog(ERRLOG, "forward: %s: cannot resolve", value);
-						server = NULL;
-					}
+					process::errlog(ERRLOG, "forward: %s: cannot resolve", value);
+					server = NULL;
 				}
 				if(server && *server) {
 					enable = true;
@@ -234,6 +212,9 @@ void forward::reload(service *cfg)
 		fp.next();
 	}
 
+	if(!refering)
+		refer = NULL;
+
 	String::upper(tmp_digest);
 	realm = tmp_realm;
 	digest = tmp_digest;
@@ -305,6 +286,20 @@ void forward::expiring(MappedRegistry *rr)
 	eXosip_unlock();
 }
 
+char *forward::referLocal(MappedRegistry *rr, const char *target, char *buffer, size_t size)
+{
+	if(!refer)
+		return NULL;
+
+	rr = find(rr->rid);		// see if caller is one of our's...
+	if(!rr)
+		return NULL;
+
+	release(rr);
+	snprintf(buffer, sizeof(buffer), "sip:%s@%s", target, refer);
+	return buffer;
+}
+	
 void forward::authenticate(int id, const char *remote_realm)
 {
 	MappedRegistry *rr;
@@ -339,7 +334,6 @@ void forward::authenticate(int id, const char *remote_realm)
 	release(rr);
 }
 
-
 void forward::registration(int id, modules::regmode_t mode)
 {
 	MappedRegistry *rr;
