@@ -332,7 +332,7 @@ static void foreground(const char *uid, const char *cfgpath, unsigned priority)
 		exit(-1);
 	}
 
-	if(!process::attach(pwd->pw_name)) {
+	if(!process::attach("sipwitch", pwd->pw_name)) {
 		fprintf(stderr, "*** sipw: no control file; exiting\n");
 		exit(-1);
 	}
@@ -352,7 +352,7 @@ static void background(const char *uid, const char *cfgpath, unsigned priority)
 	struct passwd *pwd = getuserenv(uid, cfgpath);
 	pid_t pid;
 
-	if(!process::attach(pwd->pw_name)) {
+	if(!process::attach("sipwitch", pwd->pw_name)) {
 		fprintf(stderr, "*** sipw: no control file; exiting\n");
 		exit(-1);
 	}
@@ -781,7 +781,7 @@ extern "C" int main(int argc, char **argv)
 
 		if(!stricmp(*argv, "stop") || !stricmp(*argv, "reload") || !stricmp(*argv, "abort") || !stricmp(*argv, "restart")) {
 			server::utils(user);
-			if(!process::control(user, *argv)) {
+			if(!process::control(user, "%s", *argv)) {
 				fprintf(stderr, "*** sipw: %s; server not responding\n", *argv);
 				exit(2);
 			}
@@ -790,7 +790,7 @@ extern "C" int main(int argc, char **argv)
 
 		if(!stricmp(*argv, "check")) {
 			server::utils(user);
-			if(!process::control(user, *argv)) {
+			if(!process::control(user, "%s", *argv)) {
 				fprintf(stderr, "*** sipw: %s; server cannot be checked\n", *argv);
 				exit(2);
 			}
@@ -927,11 +927,10 @@ extern "C" int main(int argc, char **argv)
 	else
 		foreground(user, cfgfile, priority);
 
-	server::reload(user);
-
 	if(restartable) 
 		restart();
 
+	server::reload(user);
 	server::startup();
 
 	if(dumping)
