@@ -150,8 +150,8 @@ private:
 
 	volatile time_t expires;
 
-	volatile char *digest;
-	volatile char *realm;
+	char * volatile digest;
+	char * volatile realm;
 	unsigned prefix;
 	unsigned range;
 	unsigned routes;
@@ -377,11 +377,8 @@ public:
 	static void clear(session *s);
 	static void close(session *s);
 	static session *access(int cid);
-	static char *sipHostid(const char *uri, char *buf, size_t size);
-	static char *sipUserid(const char *uri, char *buf, size_t size);
 	static char *sipAddress(struct sockaddr_internet *addr, char *buf, const char *user = NULL, size_t size = MAX_URI_SIZE);
 	static char *sipPublish(struct sockaddr_internet *addr, char *buf, const char *user = NULL, size_t size = MAX_URI_SIZE);
-	static char *sipIdentity(struct sockaddr_internet *addr, char *buf, const char *user = NULL, size_t size = MAX_IDENT_SIZE);
 	static char *sipContact(struct sockaddr_internet *addr, char *buf, const char *user = NULL, const char *display = NULL, size_t size = MAX_URI_SIZE);
 	static Socket::address *getAddress(const char *uri, Socket::address *addr = NULL);
 	static void siplog(osip_message_t *msg);
@@ -452,6 +449,8 @@ public:
 	static void expire(MappedRegistry *rr);
 	static void registration(int id, modules::regmode_t mode);
 	static void authenticate(int id, const char *realm);
+	static const char *referLocal(MappedRegistry *rr, const char *target, char *buffer, size_t size);
+	static const char *referRemote(MappedRegistry *rr, const char *target, char *buffer, size_t size);
 
 	static inline bool isProxied(void)
 		{return classify(NULL, NULL, NULL);};
