@@ -778,32 +778,6 @@ const char *stack::getScheme(void)
 	return "sip";
 }
 
-char *stack::sipIdentity(struct sockaddr_internet *addr, char *buf, const char *user, size_t size)
-{
-	assert(addr != NULL);
-	assert(buf != NULL);
-	assert(user == NULL || *user != 0);
-	assert(size > 0);
-
-	*buf = 0;
-	size_t len;
-
-	if(!size)
-		size = MAX_URI_SIZE;
-
-	if(!addr)
-		return NULL;
-
-	if(user) {
-		String::add(buf, size, user);
-		String::add(buf, size, "@");
-	}
-
-	len = strlen(buf);
-	Socket::getaddress((struct sockaddr *)addr, buf + len, size - len);
-	return buf;
-}
-
 char *stack::sipPublish(struct sockaddr_internet *addr, char *buf, const char *user, size_t size)
 {
 	assert(addr != NULL);
@@ -904,64 +878,6 @@ char *stack::sipAddress(struct sockaddr_internet *addr, char *buf, const char *u
 	String::add(buf, size, pbuf);
 	return buf;
 }
-
-char *stack::sipHostid(const char *addr, char *buf, size_t size)
-{
-	assert(buf != NULL);
-	assert(size > 0);
-
-	char *ep;
-	const char *cp;
-	buf[0] = 0;
-
-	if(!addr)
-		return NULL;
-
-	if(!strnicmp(addr, "sip:", 4))
-		addr += 4;
-	else if(!strnicmp(addr, "sips:", 5))
-		addr += 5;
-
-	cp = strchr(addr, '@');
-	if(cp)
-		addr = ++cp;
-	
-	String::set(buf, size, addr);
-	if(buf[0] == '[')
-		ep = strchr(buf, ']');
-	else
-		ep = strrchr(buf, ':');
-	
-	if(ep)
-		*ep = 0;
-	return buf;
-}
-
-char *stack::sipUserid(const char *addr, char *buf, size_t size)
-{
-	assert(buf != NULL);
-	assert(size > 0);
-
-	buf[0] = 0;
-	char *ep;
-
-	if(!addr)
-		return NULL;
-
-	if(!strnicmp(addr, "sip:", 4))
-		addr += 4;
-	else if(!strnicmp(addr, "sips:", 5))
-		addr += 5;
-	
-	if(!strchr(addr, '@'))
-		return NULL;
-	
-	string::set(buf, size, addr);
-	ep = strchr(buf, '@');
-	if(ep)
-		*ep = 0;
-	return buf;
-}
 	
 Socket::address *stack::getAddress(const char *addr, Socket::address *ap)
 {
