@@ -161,14 +161,14 @@ void thread::inviteRemote(stack::session *s, const char *uri_target)
 	eXosip_unlock();
 	invited = stack::create(call, cid);
 	rtpproxy::copy(&invited->proxy, &proxyinfo);
-	stack::sipUserid(uri_target, username, sizeof(username));
-	stack::sipHostid(uri_target, route, sizeof(route));
+	uri::userid(uri_target, username, sizeof(username));
+	uri::hostid(uri_target, route, sizeof(route));
 	String::set(invited->identity, sizeof(invited->identity), uri_target);
 	String::set(invited->display, sizeof(invited->display), username);
 	snprintf(invited->from, sizeof(invited->from), "<%s>", uri_target);
 	resolve.set(route, 5060);
 	if(resolve.getAddr())
-		stack::sipIdentity((struct sockaddr_internet *)resolve.getAddr(), invited->sysident, username, sizeof(invited->sysident));
+		uri::identity(resolve.getAddr(), invited->sysident, username, sizeof(invited->sysident));
 	else
 		snprintf(invited->sysident, sizeof(invited->sysident), "%s@unknown", username);
 
@@ -590,7 +590,7 @@ noproxy:
 		String::set(call->dialed, sizeof(call->dialed), target);
 		snprintf(session->identity, sizeof(session->identity), "%s:%s@%s:%s",
 			from->url->scheme, from->url->username, from->url->host, from->url->port);
-		stack::sipIdentity((struct sockaddr_internet *)from_address.getAddr(), session->sysident, from->url->username,  sizeof(session->sysident));
+		uri::identity(from_address.getAddr(), session->sysident, from->url->username,  sizeof(session->sysident));
 		if(from->displayname) {
 			String::set(session->display, sizeof(session->display), from->displayname);
 			snprintf(session->from, sizeof(session->from),
@@ -616,7 +616,7 @@ noproxy:
 		else
 			String::set(session->display, sizeof(session->display), identity);
 		stack::sipPublish(&iface, session->identity, session->sysident, sizeof(session->identity));
-		stack::sipIdentity((struct sockaddr_internet *)request_address.getAddr(), call->dialed, uri->username, sizeof(call->dialed));
+		uri::identity(request_address.getAddr(), call->dialed, uri->username, sizeof(call->dialed));
 
 		if(extension && !display[0])
 			snprintf(session->from, sizeof(session->from), 
@@ -765,6 +765,7 @@ bool thread::authorize(void)
 	registry::pattern *pp;
 	unsigned from_port = 5060, to_port = stack::sip.port, local_port = stack::sip.port;
 	const char *sep1 = "", *sep2 = "";
+	const char *refer = NULL;
 
 	if(!sevent->request || !sevent->request->to || !sevent->request->from || !sevent->request->req_uri)
 		goto invalid;
@@ -1002,6 +1003,13 @@ routing:
 
 static_routing:
 	routed = server::getRouting(target);
+	if(!routed) {
+		registry::mapped *idmap = registry::access(identity);
+		refer = server::referLocal(idmap, target, buffer, sizeof(buffer));
+		registry::detach(idmap);
+		if(refer)
+			goto redirect;
+	}
 	if(!routed)
 		goto invalid;
 
@@ -1076,6 +1084,10 @@ remote:
 	if(reginfo->type == MappedRegistry::USER && !(reginfo->profile.features & USER_PROFILE_OUTGOING))
 		goto invalid;
 
+	refer = server::referRemote(reginfo, requesting, buffer, sizeof(buffer));
+	if(refer)
+		goto redirect;
+
 	return true;
 
 invalid:
@@ -1088,6 +1100,24 @@ invalid:
 
 	send_reply(error);
 	return false;
+
+redirect:
+	osip_message_t *msg = NULL;
+
+	assert(refer != NULL && *refer != 0);
+
+	send_reply(SIP_TRYING);
+
+	Thread::yield();
+
+	eXosip_lock();
+	eXosip_call_build_refer(sevent->did, refer, &msg);
+	if(msg) {
+		osip_message_set_header(msg, "Referred-By", dbuf);
+		eXosip_call_send_request(sevent->did, msg);
+	}
+	eXosip_unlock();
+	return false;
 }
 
 void thread::send_reply(int error)
@@ -1885,14 +1915,13 @@ void thread::run(void)
 				send_reply(SIP_NOT_FOUND);
 				break;
 			}
+
 			expiration();
 			session = stack::access(sevent->cid);
 			if(!session) {
 				send_reply(SIP_NOT_FOUND);
 				break;
 			};
-			if(!authorize())
-				break;
 
 			session->parent->reinvite(this, session);
 			break;
