@@ -31,7 +31,7 @@ extern "C" {
 #include <avahi-common/timeval.h>
 };
 
-class __LOCAL zeroconf : public service::callback
+class __LOCAL zeroconf : public modules::generic
 {
 public:
 	zeroconf();
@@ -47,7 +47,7 @@ public:
 private:
 	void start(service *cfg);
 	void stop(service *cfg);
-	bool reload(service *cfg);
+	void reload(service *cfg);
 
     AvahiThreadedPoll *poller;
     AvahiClient *client;
@@ -80,7 +80,7 @@ static void group_callback(AvahiEntryGroup *g,
 };
 
 zeroconf::zeroconf() :
-service::callback(-1)
+modules::generic()
 {
 	family = AF_INET;
 	protocol = "_sip._udp";
@@ -190,7 +190,7 @@ void zeroconf::start(service *cfg)
     avahi_threaded_poll_start(poller);
 }
 
-bool zeroconf::reload(service *cfg)
+void zeroconf::reload(service *cfg)
 {
 	assert(cfg != NULL);
 
@@ -199,7 +199,7 @@ bool zeroconf::reload(service *cfg)
 	static bool started = false;
 
 	if(started)
-		return true;
+		return;
 
 	started = true;
 
@@ -222,12 +222,11 @@ bool zeroconf::reload(service *cfg)
 		}
 		sp.next();
 	}
-	return true;
 }
 
 #else
 
-class __LOCAL zeroconf : public service::callback
+class __LOCAL zeroconf : modules::generic
 {
 public:
 	static zeroconf plugin;
@@ -236,7 +235,7 @@ public:
 };
 
 zeroconf::zeroconf() :
-service::callback(-1)
+modules::generic()
 {
 	process::errlog(ERRLOG, "zeroconf plugin could not be built");
 }
